@@ -1,10 +1,10 @@
-from ._version import __version__
-del _version
+import sys
+
+from picomc._version import __version__
+from picomc.cli import picomc_cli
 
 MINPYVERSION = (3, 7, 0)
 
-import sys
-
 if sys.version_info < MINPYVERSION:
     print("picomc, version {}".format(__version__))
     print(
@@ -13,5 +13,6 @@ if sys.version_info < MINPYVERSION:
     )
     sys.exit(1)
 
-# This is referenced in setup.py
-from picomc.main import main
+
+def main():
+    picomc_cli()
