@@ -1,7 +1,9 @@
 import uuid
 
+from picomc.errors import RefreshError, ValidationError
 from picomc.logging import logger
-from picomc.yggdrasil import MojangYggdrasil, RefreshError
+from picomc.msapi import MicrosoftAuthApi
+from picomc.yggdrasil import MojangYggdrasil
 
 
 class NAMESPACE_NULL:
@@ -29,7 +31,12 @@ class Account:
 
     @classmethod
     def from_config(cls, am, name, config):
-        c = OnlineAccount if config.get("online", False) else OfflineAccount
+        if config.get("microsoft", False):
+            c = MicrosoftAccount
+        elif config.get("online", False):
+            c = OnlineAccount
+        else:
+            c = OfflineAccount
         return c(name=name, _am=am, **config)
 
 
@@ -49,6 +56,9 @@ class OfflineAccount(Account):
     def refresh(self):
         return False
 
+    def can_launch_game(self):
+        return True
+
 
 class OnlineAccount(Account):
     DEFAULTS = {
@@ -103,6 +113,54 @@ class OnlineAccount(Account):
         self.fresh = True
         self.save()
 
+    def can_launch_game(self):
+        return self.is_authenticated
+
+
+class MicrosoftAccount(Account):
+    DEFAULTS = {
+        "uuid": "-",
+        "online": True,
+        "microsoft": True,
+        "gname": "-",
+        "access_token": "-",
+        "refresh_token": "-",
+        "is_authenticated": False,
+    }
+
+    @classmethod
+    def new(cls, am, name):
+        return cls(name=name, _am=am)
+
+    def refresh(self, force=False):
+        if not self.is_authenticated:
+            raise RefreshError("Account is not authenticated, cannot refresh")
+        try:
+            valid = self._am.msapi.validate(self.access_token)
+        except ValidationError as e:
+            raise RefreshError(e)
+        if valid:
+            logger.debug("msa: token still valid")
+            return False
+        else:
+            logger.debug("msa: token not valid anymore, refreshing")
+            self.access_token, self.refresh_token = self._am.msapi.refresh(
+                self.refresh_token
+            )
+            self.save()
+            return True
+
+    def authenticate(self):
+        self.access_token, self.refresh_token = self._am.msapi.authenticate()
+        profile = self._am.msapi.get_profile(self.access_token)
+        self.gname = profile["name"]
+        self.uuid = profile["id"]
+        self.is_authenticated = True
+        self.save()
+
+    def can_launch_game(self):
+        return self.is_authenticated
+
 
 class AccountError(ValueError):
     def __str__(self):
@@ -122,6 +180,7 @@ class AccountManager:
     def __init__(self, launcher):
         self.config = launcher.config_manager.get(self.CONFIG_FILE, init=DEFAULT_CONFIG)
         self.yggdrasil = MojangYggdrasil(self.config["client_token"])
+        self.msapi = MicrosoftAuthApi()
 
     def list(self):
         return self.config["accounts"].keys()
