@@ -1,7 +1,14 @@
 import click
 
-from picomc.account import AccountError, OfflineAccount, OnlineAccount, RefreshError
+from picomc.account import (
+    AccountError,
+    MicrosoftAccount,
+    OfflineAccount,
+    OnlineAccount,
+    RefreshError,
+)
 from picomc.cli.utils import pass_account_manager
+from picomc.logging import logger
 from picomc.yggdrasil import AuthenticationError
 
 
@@ -24,23 +31,29 @@ def _list(am):
         lines = ("{}{}".format("* " if am.is_default(u) else "  ", u) for u in alist)
         print("\n".join(lines))
     else:
-        print("No accounts.")
+        logger.info("No accounts.")
 
 
 @account_cli.command()
 @account_cmd
 @click.argument("mojang_username", required=False)
+@click.option("--ms", "--microsoft", "microsoft", is_flag=True, default=False)
 @pass_account_manager
-def create(am, account, mojang_username):
+def create(am, account, mojang_username, microsoft):
     """Create an account."""
     try:
         if mojang_username:
+            if microsoft:
+                logger.error("Do not use --microsoft with mojang_username argument")
+                return
             acc = OnlineAccount.new(am, account, mojang_username)
+        elif microsoft:
+            acc = MicrosoftAccount.new(am, account)
         else:
             acc = OfflineAccount.new(am, account)
         am.add(acc)
     except AccountError as e:
-        print(e)
+        logger.error("Could not create account: %s", e)
 
 
 @account_cli.command()
@@ -48,14 +61,27 @@ def create(am, account, mojang_username):
 @pass_account_manager
 def authenticate(am, account):
     """Retrieve access token from Mojang servers using password."""
-    import getpass
 
     try:
         a = am.get(account)
-        p = getpass.getpass("Password: ")
-        a.authenticate(p)
+    except AccountError:
+        logger.error("AccountError", exc_info=True)
+        return
+
+    try:
+        if isinstance(a, OfflineAccount):
+            logger.error("Offline accounts cannot be authenticated")
+        elif isinstance(a, OnlineAccount):
+            import getpass
+
+            p = getpass.getpass("Password: ")
+            a.authenticate(p)
+        elif isinstance(a, MicrosoftAccount):
+            a.authenticate()
+        else:
+            logger.error("Unknown account type")
     except AuthenticationError as e:
-        print(e)
+        logger.error("Authentication failed: %s", e)
 
 
 @account_cli.command()
@@ -67,7 +93,7 @@ def refresh(am, account):
         a = am.get(account)
         a.refresh()
     except (AccountError, RefreshError) as e:
-        print(e)
+        logger.error("Could not refresh account: %s", e)
 
 
 @account_cli.command()
@@ -78,7 +104,7 @@ def remove(am, account):
     try:
         am.remove(account)
     except AccountError as e:
-        print(e)
+        logger.error("Could not remove account: %s", e)
 
 
 @account_cli.command()
@@ -90,7 +116,7 @@ def setdefault(am, account):
         default = am.get(account)
         am.set_default(default)
     except AccountError as e:
-        print(e)
+        logger.error("Could not set default account: %s", e)
 
 
 def register_account_cli(picomc_cli):
